# Flux RestFul Client (Python!)

[![PyPI version](https://badge.fury.io/py/flux-restful-client.svg)](https://badge.fury.io/py/flux-restful-client)
[![main](https://github.com/flux-framework/flux-restful-api/actions/workflows/python-tests.yml/badge.svg)](https://github.com/flux-framework/flux-restful-api/actions/workflows/python-tests.yml)

The Flux RESTFul client in Python makes it easy to interact with the [Flux RESTFul API](https://github.com/flux-framework/flux-restful-api).

You can see the [⭐️ Documentation ⭐️](https://flux-framework.org/flux-restful-api/getting_started/user-guide.html) for complete details
for installation and usage.

#### Release

SPDX-License-Identifier: LGPL-3.0

LLNL-CODE-764420
